from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlopeCls:
	"""Slope commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slope", core, parent)

	def set(self, edge: enums.SlopeType) -> None:
		"""SCPI: [SENSe]:PMETer:TRIGger:SLOPe \n
		Snippet: driver.applications.k18AmplifierEt.sense.pmeter.trigger.slope.set(edge = enums.SlopeType.NEGative) \n
		This command selects the trigger condition for external power triggers. \n
			:param edge: POSitive The measurement starts in case the trigger signal shows a positive edge. NEGative The measurement starts in case the trigger signal shows a negative edge.
		"""
		param = Conversions.enum_scalar_to_str(edge, enums.SlopeType)
		self._core.io.write(f'SENSe:PMETer:TRIGger:SLOPe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SlopeType:
		"""SCPI: [SENSe]:PMETer:TRIGger:SLOPe \n
		Snippet: value: enums.SlopeType = driver.applications.k18AmplifierEt.sense.pmeter.trigger.slope.get() \n
		This command selects the trigger condition for external power triggers. \n
			:return: edge: POSitive The measurement starts in case the trigger signal shows a positive edge. NEGative The measurement starts in case the trigger signal shows a negative edge."""
		response = self._core.io.query_str(f'SENSe:PMETer:TRIGger:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SlopeType)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeShiftCls:
	"""TimeShift commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("timeShift", core, parent)

	def set(self, time_shift: float, channel=repcap.Channel.Default) -> None:
		"""SCPI: CONFigure:WLAN:SMAPping:TX<ch>:TIMeshift \n
		Snippet: driver.applications.k91Wlan.configure.wlan.smapping.tx.timeShift.set(time_shift = 1.0, channel = repcap.Channel.Default) \n
		This remote control command specifies the timeshift for a specific antenna. \n
			:param time_shift: Time shift (in s) for specification of user defined CSD (cyclic delay diversity) for the Spatial Mapping. Range: -32 ns to 32 ns , Unit: S
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Tx')
		"""
		param = Conversions.decimal_value_to_str(time_shift)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'CONFigure:WLAN:SMAPping:TX{channel_cmd_val}:TIMeshift {param}')

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: CONFigure:WLAN:SMAPping:TX<ch>:TIMeshift \n
		Snippet: value: float = driver.applications.k91Wlan.configure.wlan.smapping.tx.timeShift.get(channel = repcap.Channel.Default) \n
		This remote control command specifies the timeshift for a specific antenna. \n
			:param channel: optional repeated capability selector. Default value: Ch1 (settable in the interface 'Tx')
			:return: time_shift: Time shift (in s) for specification of user defined CSD (cyclic delay diversity) for the Spatial Mapping. Range: -32 ns to 32 ns , Unit: S"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'CONFigure:WLAN:SMAPping:TX{channel_cmd_val}:TIMeshift?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NfftCls:
	"""Nfft commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nfft", core, parent)

	def set(self, loffset: float) -> None:
		"""SCPI: [SENSe]:DIRected:NFFT \n
		Snippet: driver.applications.k50Spurious.sense.directed.nfft.set(loffset = 1.0) \n
		Defines the number of FFTs to be performed for all spurs in the directed search measurement. \n
			:param loffset: integer Range: 1 to 20, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(loffset)
		self._core.io.write(f'SENSe:DIRected:NFFT {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DIRected:NFFT \n
		Snippet: value: float = driver.applications.k50Spurious.sense.directed.nfft.get() \n
		Defines the number of FFTs to be performed for all spurs in the directed search measurement. \n
			:return: loffset: integer Range: 1 to 20, Unit: DB"""
		response = self._core.io.query_str(f'SENSe:DIRected:NFFT?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, result: enums.ResultTypeNr5G, state: bool) -> None:
		"""SCPI: [SENSe]:NR5G:EFILter:FPARameters:STATe \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.efilter.fparameters.state.set(result = enums.ResultTypeNr5G.AAPFail, state = False) \n
		This command turns an event filter on and off. Turning on an event filter adds it to the filter list and removes the
		results from the result summary that do not fulfill the filter conditions. Turning it off removes it from the list.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Define a filter condition ([SENSe:]NR5G:EFILter:FPARameters) . \n
			:param result: CRESt | DSQP | DSSF | DSST | DSTS | FSOFfset | EVM | OVLD | FERRor | GIMBalance | IQOFfset | MODulation | NORB | OSTP | RSTP | RSSI | SSPower | CSIPower | PCHannel | POWer | PPRE | PSIGnal | QUADrature | SERRor | MID | TSTamp | TSDelta | SSTate | APFail | AAPFail | ARPFail | SPFail | BLER | TPUT Selects the result that you want to add a filter for.
			:param state: ON | OFF | 1 | 0
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('result', result, DataType.Enum, enums.ResultTypeNr5G), ArgSingle('state', state, DataType.Boolean))
		self._core.io.write(f'SENSe:NR5G:EFILter:FPARameters:STATe {param}'.rstrip())

	# noinspection PyTypeChecker
	class StateStruct(StructBase):
		"""Response structure. Fields: \n
			- Result: enums.ResultTypeNr5G: CRESt | DSQP | DSSF | DSST | DSTS | FSOFfset | EVM | OVLD | FERRor | GIMBalance | IQOFfset | MODulation | NORB | OSTP | RSTP | RSSI | SSPower | CSIPower | PCHannel | POWer | PPRE | PSIGnal | QUADrature | SERRor | MID | TSTamp | TSDelta | SSTate | APFail | AAPFail | ARPFail | SPFail | BLER | TPUT Selects the result that you want to add a filter for.
			- State: bool: ON | OFF | 1 | 0"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Result', enums.ResultTypeNr5G),
			ArgStruct.scalar_bool('State')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Result: enums.ResultTypeNr5G = None
			self.State: bool = None

	def get(self) -> StateStruct:
		"""SCPI: [SENSe]:NR5G:EFILter:FPARameters:STATe \n
		Snippet: value: StateStruct = driver.applications.k14Xnr5G.sense.nr5G.efilter.fparameters.state.get() \n
		This command turns an event filter on and off. Turning on an event filter adds it to the filter list and removes the
		results from the result summary that do not fulfill the filter conditions. Turning it off removes it from the list.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Define a filter condition ([SENSe:]NR5G:EFILter:FPARameters) . \n
			:return: structure: for return value, see the help for StateStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:NR5G:EFILter:FPARameters:STATe?', self.__class__.StateStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ChirpCls:
	"""Chirp commands group definition. 7 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("chirp", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def timing(self):
		"""timing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_timing'):
			from .Timing import TimingCls
			self._timing = TimingCls(self._core, self._cmd_group)
		return self._timing

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import PhaseCls
			self._phase = PhaseCls(self._core, self._cmd_group)
		return self._phase

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def fmSettling(self):
		"""fmSettling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmSettling'):
			from .FmSettling import FmSettlingCls
			self._fmSettling = FmSettlingCls(self._core, self._cmd_group)
		return self._fmSettling

	@property
	def pmSettling(self):
		"""pmSettling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmSettling'):
			from .PmSettling import PmSettlingCls
			self._pmSettling = PmSettlingCls(self._core, self._cmd_group)
		return self._pmSettling

	def clone(self) -> 'ChirpCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ChirpCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, result_type: enums.ResultTypeA, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:NPRatio:RESult \n
		Snippet: value: float = driver.calculate.npratio.result.get(result_type = enums.ResultTypeA.ALL, window = repcap.Window.Default) \n
		Queries the power results of the noise power ratio measurement. \n
			:param result_type: CPOWer | NPOWer | NPRatio | ALL CPOWer Returns the total measured power divided by the channel bandwidth (without notches) or integration bandwidth (with notches) in dBm/Hz NPOWer Returns the power measured in each notch divided by the notch bandwidth in dBm/Hz NPRatio Returns the ratio of the total channel power density divided by the notch power density for each notch in dB ALL Returns all power results for the channel and n defined notches in the following order: ChannelPowerDens,NotchPowerDens1,..,NotchPowerDensn,NPR1,..,NPRn
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: result_type_result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeA)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:NPRatio:RESult? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RbwCls:
	"""Rbw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rbw", core, parent)

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:PSPectrum:RBW \n
		Snippet: value: float = driver.applications.k6Pulse.calculate.pspectrum.rbw.get(window = repcap.Window.Default) \n
		Queries the resulting resolution bandwidth for the spectrum. Depends on the block size (see method RsFsw.Applications.
		K6_Pulse.Calculate.Pspectrum.BlockSize.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: rbw: Unit: Hz"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:PSPectrum:RBW?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DistributionCls:
	"""Distribution commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("distribution", core, parent)

	@property
	def llines(self):
		"""llines commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_llines'):
			from .Llines import LlinesCls
			self._llines = LlinesCls(self._core, self._cmd_group)
		return self._llines

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def nbins(self):
		"""nbins commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nbins'):
			from .Nbins import NbinsCls
			self._nbins = NbinsCls(self._core, self._cmd_group)
		return self._nbins

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import PhaseCls
			self._phase = PhaseCls(self._core, self._cmd_group)
		return self._phase

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def timing(self):
		"""timing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_timing'):
			from .Timing import TimingCls
			self._timing = TimingCls(self._core, self._cmd_group)
		return self._timing

	@property
	def emodel(self):
		"""emodel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_emodel'):
			from .Emodel import EmodelCls
			self._emodel = EmodelCls(self._core, self._cmd_group)
		return self._emodel

	@property
	def tsidelobe(self):
		"""tsidelobe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tsidelobe'):
			from .Tsidelobe import TsidelobeCls
			self._tsidelobe = TsidelobeCls(self._core, self._cmd_group)
		return self._tsidelobe

	def clone(self) -> 'DistributionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DistributionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def set(self, result: enums.DdpdResult, window=repcap.Window.Default) -> None:
		"""SCPI: CONFigure:DDPD:WINDow<n>:RESult \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.window.result.set(result = enums.DdpdResult.ACB1, window = repcap.Window.Default) \n
		Configures the result type of the DDPD Results result display. \n
			:param result: EVM Error Vector Magnitude ACL1 AClrLower1 ACU1 AClrUpper1 ACB1 AClrBalanced1
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.enum_scalar_to_str(result, enums.DdpdResult)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CONFigure:DDPD:WINDow{window_cmd_val}:RESult {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.DdpdResult:
		"""SCPI: CONFigure:DDPD:WINDow<n>:RESult \n
		Snippet: value: enums.DdpdResult = driver.applications.k18AmplifierEt.configure.ddpd.window.result.get(window = repcap.Window.Default) \n
		Configures the result type of the DDPD Results result display. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: result: EVM Error Vector Magnitude ACL1 AClrLower1 ACU1 AClrUpper1 ACB1 AClrBalanced1"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CONFigure:DDPD:WINDow{window_cmd_val}:RESult?')
		return Conversions.str_to_scalar_enum(response, enums.DdpdResult)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CstateCls:
	"""Cstate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cstate", core, parent)

	def get(self) -> str:
		"""SCPI: CONFigure:GENerator:CONNection:CSTate \n
		Snippet: value: str = driver.configure.generator.connection.cstate.get() \n
		Queries the state of the connected signal generator. \n
			:return: connection_state: UNKNown no signal generator connected CONNected connection established NCONnected connection could not be established, possibly due to an incompatible instrument or invalid IP address"""
		response = self._core.io.query_str(f'CONFigure:GENerator:CONNection:CSTate?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:NR5G:FRAMe:COUNt:AUTO \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.frame.count.auto.set(state = False) \n
		This command turns automatic selection of the number of frames to analyze on and off. \n
			:param state: ON | 1 Selects the analyzed number of frames as specified by 3GPP. OFF | 0 Turns on manual selection of the number of frames.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:NR5G:FRAMe:COUNt:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:NR5G:FRAMe:COUNt:AUTO \n
		Snippet: value: bool = driver.applications.k14Xnr5G.sense.nr5G.frame.count.auto.get() \n
		This command turns automatic selection of the number of frames to analyze on and off. \n
			:return: state: ON | 1 Selects the analyzed number of frames as specified by 3GPP. OFF | 0 Turns on manual selection of the number of frames."""
		response = self._core.io.query_str(f'SENSe:NR5G:FRAMe:COUNt:AUTO?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TsidelobeCls:
	"""Tsidelobe commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tsidelobe", core, parent)

	def set(self, param: enums.PulseSidelobeItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:PSPectrum:TSIDelobe \n
		Snippet: driver.applications.k6Pulse.calculate.pspectrum.tsidelobe.set(param = enums.PulseSidelobeItems.AMPower, window = repcap.Window.Default) \n
		Configures the Time Sidelobe Parameter Spectrum result display. This command is only available if the additional option
		R&S FSW-K6S is installed. \n
			:param param: PSLevel | ISLevel | MWIDth | SDELay | CRATio | IMPower | AMPower | PCORrelation | MPHase | MFRequency Time sidelobe parameter to be displayed on the x-axis. For a description of the available parameters see 'Time sidelobe parameters'. PSLevel peak to sidelobe level ISLevel integrated sidelobe level MWIDth mainlobe 3 dB width SDELay sidelobe delay CRATio compression ratio IMPower integrated mainlobe power AMPower average mainlobe power PCORrelation peak correlation MPHase mainlobe phase MFRequency mainlobe frequency
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(param, enums.PulseSidelobeItems)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:PSPectrum:TSIDelobe {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.PulseSidelobeItems:
		"""SCPI: CALCulate<n>:PSPectrum:TSIDelobe \n
		Snippet: value: enums.PulseSidelobeItems = driver.applications.k6Pulse.calculate.pspectrum.tsidelobe.get(window = repcap.Window.Default) \n
		Configures the Time Sidelobe Parameter Spectrum result display. This command is only available if the additional option
		R&S FSW-K6S is installed. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: param: PSLevel | ISLevel | MWIDth | SDELay | CRATio | IMPower | AMPower | PCORrelation | MPHase | MFRequency Time sidelobe parameter to be displayed on the x-axis. For a description of the available parameters see 'Time sidelobe parameters'. PSLevel peak to sidelobe level ISLevel integrated sidelobe level MWIDth mainlobe 3 dB width SDELay sidelobe delay CRATio compression ratio IMPower integrated mainlobe power AMPower average mainlobe power PCORrelation peak correlation MPHase mainlobe phase MFRequency mainlobe frequency"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:PSPectrum:TSIDelobe?')
		return Conversions.str_to_scalar_enum(response, enums.PulseSidelobeItems)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DurationCls:
	"""Duration commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("duration", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:DURation \n
		Snippet: value: float = driver.applications.k10Xlte.sense.sweep.duration.get() \n
		No command help available \n
			:return: time: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:DURation?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def stat(self):
		"""stat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stat'):
			from .Stat import StatCls
			self._stat = StatCls(self._core, self._cmd_group)
		return self._stat

	def set(self, coupling: enums.CouplingRosc) -> None:
		"""SCPI: CONFigure:WLAN:ANTMatrix:SOURce:ROSCillator:SOURce \n
		Snippet: driver.applications.k91Wlan.configure.wlan.antMatrix.source.roscillator.source.set(coupling = enums.CouplingRosc.AUTO) \n
		This remote control command determines whether the reference frequency for the primary and secondary devices in a
		simultaneous MIMO setup are coupled or not. \n
			:param coupling: AUTO | EXTernal | OFF Coupling mode AUTO Secondaries set to the same external reference source as primary. Use an R&S Z11 trigger box to send to the same trigger to all devices (see TRIG:SEQ:SOUR TUN. EXTernal Secondaries' reference source is set to external. Configure a trigger output from the primary (see method RsFsw.Applications.K10x_Lte.Output.Trigger.Otype.set) . OFF Secondaries' reference source is set to internal.
		"""
		param = Conversions.enum_scalar_to_str(coupling, enums.CouplingRosc)
		self._core.io.write(f'CONFigure:WLAN:ANTMatrix:SOURce:ROSCillator:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CouplingRosc:
		"""SCPI: CONFigure:WLAN:ANTMatrix:SOURce:ROSCillator:SOURce \n
		Snippet: value: enums.CouplingRosc = driver.applications.k91Wlan.configure.wlan.antMatrix.source.roscillator.source.get() \n
		This remote control command determines whether the reference frequency for the primary and secondary devices in a
		simultaneous MIMO setup are coupled or not. \n
			:return: coupling: AUTO | EXTernal | OFF Coupling mode AUTO Secondaries set to the same external reference source as primary. Use an R&S Z11 trigger box to send to the same trigger to all devices (see TRIG:SEQ:SOUR TUN. EXTernal Secondaries' reference source is set to external. Configure a trigger output from the primary (see method RsFsw.Applications.K10x_Lte.Output.Trigger.Otype.set) . OFF Secondaries' reference source is set to internal."""
		response = self._core.io.query_str(f'CONFigure:WLAN:ANTMatrix:SOURce:ROSCillator:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.CouplingRosc)

	def clone(self) -> 'SourceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SourceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TestCls:
	"""Test commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("test", core, parent)

	@property
	def redo(self):
		"""redo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_redo'):
			from .Redo import RedoCls
			self._redo = RedoCls(self._core, self._cmd_group)
		return self._redo

	@property
	def undo(self):
		"""undo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_undo'):
			from .Undo import UndoCls
			self._undo = UndoCls(self._core, self._cmd_group)
		return self._undo

	def clone(self) -> 'TestCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TestCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def get(self) -> bool:
		"""SCPI: CALibration:MCGD:STATe \n
		Snippet: value: bool = driver.applications.k17Mcgd.calibration.mcgd.state.get() \n
		This command queries the calibration status of the Multi-Carrier 'Group Delay' application. \n
			:return: state: ON | 1 Calibration has been performed, reference data is available. OFF | 0 Calibration has not yet been performed or is currently running, reference data is not yet available."""
		response = self._core.io.query_str(f'CALibration:MCGD:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	def get(self, trace: enums.TraceTypeNumeric, window=repcap.Window.Default) -> str:
		"""SCPI: TRACe<n>[:DATA]:X \n
		Snippet: value: str = driver.applications.k18AmplifierEt.trace.data.x.get(trace = enums.TraceTypeNumeric.TRACe1, window = repcap.Window.Default) \n
		This command queries the measurement results as displayed on the x-axis in the graphical result displays. \n
			:param trace: TRACE1 | ... | TRACE6 Selects the trace to be queried. Note that the available number of traces depends on the result display. For example, the 'Magnitude Capture' result display only supports TRACE1, while the 'Time Domain' result display supports TRACE1 to TRACE6.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: result: numeric value X-axis values of the captured samples in chronological order."""
		param = Conversions.enum_scalar_to_str(trace, enums.TraceTypeNumeric)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'TRACe{window_cmd_val}:DATA:X? {param}')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: INPut:GAIN:STATe \n
		Snippet: driver.inputPy.gain.state.set(state = False) \n
		This command turns the internal preamplifier on and off. It requires the optional preamplifier hardware. Note that if an
		optional external preamplifier is activated, the internal preamplifier is automatically disabled, and vice versa.
		This function is not available for input from the optional 'Digital Baseband' interface. For R&S FSW 8 or 13 models, the
		preamplification is defined by method RsFsw.Applications.K10x_Lte.InputPy.Gain.Value.set. For R&S FSW 26 or higher models,
		the input signal is amplified by 30 dB if the preamplifier is activated. If option R&S FSW-B22 is installed, the
		preamplifier is only active below 7 GHz. If option R&S FSW-B24 is installed, the preamplifier is active for all
		frequencies. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'INPut:GAIN:STATe {param}')

	def get(self) -> bool:
		"""SCPI: INPut:GAIN:STATe \n
		Snippet: value: bool = driver.inputPy.gain.state.get() \n
		This command turns the internal preamplifier on and off. It requires the optional preamplifier hardware. Note that if an
		optional external preamplifier is activated, the internal preamplifier is automatically disabled, and vice versa.
		This function is not available for input from the optional 'Digital Baseband' interface. For R&S FSW 8 or 13 models, the
		preamplification is defined by method RsFsw.Applications.K10x_Lte.InputPy.Gain.Value.set. For R&S FSW 26 or higher models,
		the input signal is amplified by 30 dB if the preamplifier is activated. If option R&S FSW-B22 is installed, the
		preamplifier is only active below 7 GHz. If option R&S FSW-B24 is installed, the preamplifier is active for all
		frequencies. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'INPut:GAIN:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LdeltaCls:
	"""Ldelta commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ldelta", core, parent)

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:FMEasurement:LIMit<li>:LDELta \n
		Snippet: value: float = driver.calculate.marker.function.fmeasurement.limit.ldelta.get(window = repcap.Window.Default, marker = repcap.Marker.Default, limitIx = repcap.LimitIx.Default) \n
		This command queries the vertical distance from the marker position to the limit line. The unit is dB. If the marker has
		been assigned to a different trace than the limit line, or if no limit ine is defined for the marker position, the
		command returns -200. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: amplitude: Vertical distance to the limit line in dB."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:FMEasurement:LIMit{limitIx_cmd_val}:LDELta?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.TriggerSourceH) -> None:
		"""SCPI: TRIGger[:SEQuence]:SOURce \n
		Snippet: driver.applications.k91Wlan.trigger.sequence.source.set(source = enums.TriggerSourceH.AF) \n
		This command selects the trigger source. For details on the available trigger sources, see 'Trigger Source'.
		Note on external triggers: If a measurement is configured to wait for an external trigger signal in a remote control
		program, remote control is blocked until the trigger is received and the program can continue. Make sure that this
		situation is avoided in your remote control programs. \n
			:param source: IMMediate Free Run EXTernal Trigger signal from the 'Trigger Input' connector. EXT2 Trigger signal from the 'Trigger Input/Output' connector. For R&S FSW85 models, Trigger 2 is not available due to the second RF input connector on the front panel. The trigger signal is taken from the 'Trigger Input/Output' connector on the rear panel. Note: Connector must be configured for 'Input'. EXT3 Trigger signal from the 'TRIGGER 3 INPUT/ OUTPUT' connector. Note: Connector must be configured for 'Input'. RFPower First intermediate frequency (Frequency and time domain measurements only.) Not available for input from the optional 'Digital Baseband' interface or the optional 'Analog Baseband' interface. IFPower Second intermediate frequency Not available for input from the optional 'Digital Baseband' interface. For input from the optional 'Analog Baseband' interface, this parameter is interpreted as BBPower for compatibility reasons. IQPower Magnitude of sampled I/Q data For applications that process I/Q data, such as the I/Q Analyzer or optional applications. Not available for input from the optional 'Digital Baseband' interface or the optional 'Analog Baseband' interface. TIME Time interval BBPower Baseband power (for digital input via the optional 'Digital Baseband' interface Baseband power (for digital input via the optional 'Digital Baseband' interface or the optional 'Analog Baseband' interface PSEN External power sensor GP0 | GP1 | GP2 | GP3 | GP4 | GP5 For applications that process I/Q data, such as the I/Q Analyzer or optional applications, and only if the optional 'Digital Baseband' interface is available. Defines triggering of the measurement directly via the LVDS connector. The parameter specifies which general-purpose bit (0 to 5) provides the trigger data. The assignment of the general-purpose bits used by the Digital IQ trigger to the LVDS connector pins is provided in 'Digital I/Q'. TUNit If activated, the measurement is triggered by a connected R&S FS-Z11 trigger unit, simultaneously for all connected analyzers. For details see 'Trigger synchronization using an R&S FS-Z11 trigger unit'.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.TriggerSourceH)
		self._core.io.write(f'TRIGger:SEQuence:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.TriggerSourceH:
		"""SCPI: TRIGger[:SEQuence]:SOURce \n
		Snippet: value: enums.TriggerSourceH = driver.applications.k91Wlan.trigger.sequence.source.get() \n
		This command selects the trigger source. For details on the available trigger sources, see 'Trigger Source'.
		Note on external triggers: If a measurement is configured to wait for an external trigger signal in a remote control
		program, remote control is blocked until the trigger is received and the program can continue. Make sure that this
		situation is avoided in your remote control programs. \n
			:return: source: IMMediate Free Run EXTernal Trigger signal from the 'Trigger Input' connector. EXT2 Trigger signal from the 'Trigger Input/Output' connector. For R&S FSW85 models, Trigger 2 is not available due to the second RF input connector on the front panel. The trigger signal is taken from the 'Trigger Input/Output' connector on the rear panel. Note: Connector must be configured for 'Input'. EXT3 Trigger signal from the 'TRIGGER 3 INPUT/ OUTPUT' connector. Note: Connector must be configured for 'Input'. RFPower First intermediate frequency (Frequency and time domain measurements only.) Not available for input from the optional 'Digital Baseband' interface or the optional 'Analog Baseband' interface. IFPower Second intermediate frequency Not available for input from the optional 'Digital Baseband' interface. For input from the optional 'Analog Baseband' interface, this parameter is interpreted as BBPower for compatibility reasons. IQPower Magnitude of sampled I/Q data For applications that process I/Q data, such as the I/Q Analyzer or optional applications. Not available for input from the optional 'Digital Baseband' interface or the optional 'Analog Baseband' interface. TIME Time interval BBPower Baseband power (for digital input via the optional 'Digital Baseband' interface Baseband power (for digital input via the optional 'Digital Baseband' interface or the optional 'Analog Baseband' interface PSEN External power sensor GP0 | GP1 | GP2 | GP3 | GP4 | GP5 For applications that process I/Q data, such as the I/Q Analyzer or optional applications, and only if the optional 'Digital Baseband' interface is available. Defines triggering of the measurement directly via the LVDS connector. The parameter specifies which general-purpose bit (0 to 5) provides the trigger data. The assignment of the general-purpose bits used by the Digital IQ trigger to the LVDS connector pins is provided in 'Digital I/Q'. TUNit If activated, the measurement is triggered by a connected R&S FS-Z11 trigger unit, simultaneously for all connected analyzers. For details see 'Trigger synchronization using an R&S FS-Z11 trigger unit'."""
		response = self._core.io.query_str(f'TRIGger:SEQuence:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerSourceH)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ...........Internal.Types import DataType
from ...........Internal.ArgSingleList import ArgSingleList
from ...........Internal.ArgSingle import ArgSingle
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def get(self, result: enums.SelectAll = None, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default) -> float:
		"""SCPI: FETCh[:CC<cc>][:ISRC][:FRAMe<fr>]:SUMMary:EVM:SDPB:MAXimum \n
		Snippet: value: float = driver.applications.k14Xnr5G.fetch.cc.isrc.frame.summary.evm.sdpb.maximum.get(result = enums.SelectAll.ALL, carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default) \n
		This command queries the EVM of all PUSCH DMRS resource elements with a PI/2 BPSK modulation.
			INTRO_CMD_HELP: method RsFsw.Applications.K14x_Nr5G.Fetch.All.Summary.Evm.Sdpb.get_ queries the average result over all carriers. Prerequisites: \n
			- Select to evaluate all carriers ([SENSe:]NR5G:RSUMmary:CCResult) . \n
			:param result: ALL
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:return: evm: EVM in % or dB."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('result', result, DataType.Enum, enums.SelectAll, is_optional=True))
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		response = self._core.io.query_str(f'FETCh:CC{carrierComponent_cmd_val}:ISRC:FRAMe{frame_cmd_val}:SUMMary:EVM:SDPB:MAXimum? {param}'.rstrip())
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaskCls:
	"""Mask commands group definition. 15 total commands, 7 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mask", core, parent)

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def upper(self):
		"""upper commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_upper'):
			from .Upper import UpperCls
			self._upper = UpperCls(self._core, self._cmd_group)
		return self._upper

	@property
	def lower(self):
		"""lower commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_lower'):
			from .Lower import LowerCls
			self._lower = LowerCls(self._core, self._cmd_group)
		return self._lower

	@property
	def currentDirectory(self):
		"""currentDirectory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_currentDirectory'):
			from .CurrentDirectory import CurrentDirectoryCls
			self._currentDirectory = CurrentDirectoryCls(self._core, self._cmd_group)
		return self._currentDirectory

	@property
	def span(self):
		"""span commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_span'):
			from .Span import SpanCls
			self._span = SpanCls(self._core, self._cmd_group)
		return self._span

	def delete(self, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:MASK:DELete \n
		Snippet: driver.calculate.mask.delete(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:MASK:DELete')

	def delete_with_opc(self, window=repcap.Window.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		"""SCPI: CALCulate<n>:MASK:DELete \n
		Snippet: driver.calculate.mask.delete_with_opc(window = repcap.Window.Default) \n
		No command help available \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MASK:DELete', opc_timeout_ms)

	def clone(self) -> 'MaskCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MaskCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NtxuCls:
	"""Ntxu commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ntxu", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: [SENSe]:POWer:SEM:NTXU \n
		Snippet: driver.applications.k14Xnr5G.sense.power.sem.ntxu.set(value = 1.0) \n
		This command defines the parameter NTXU that defines the position of the spectrum emission mask for 1-H base stations.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a 1-H base station (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Bstation.set) . \n
			:param value: No help available
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'SENSe:POWer:SEM:NTXU {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:SEM:NTXU \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.power.sem.ntxu.get() \n
		This command defines the parameter NTXU that defines the position of the spectrum emission mask for 1-H base stations.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a 1-H base station (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Bstation.set) . \n
			:return: value: No help available"""
		response = self._core.io.query_str(f'SENSe:POWer:SEM:NTXU?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RightCls:
	"""Right commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("right", core, parent)

	def set(self, limit: float, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:X:SLIMits:RIGHt \n
		Snippet: driver.calculate.marker.x.slimits.right.set(limit = 1.0, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command defines the right limit of the marker search range for all markers in all windows.
		If you perform a measurement in the time domain, this command limits the range of the trace to be analyzed. \n
			:param limit: The value range depends on the frequency range or sweep time. The unit is Hz for frequency domain measurements and s for time domain measurements. Unit: HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.decimal_value_to_str(limit)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:X:SLIMits:RIGHt {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:X:SLIMits:RIGHt \n
		Snippet: value: float = driver.calculate.marker.x.slimits.right.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command defines the right limit of the marker search range for all markers in all windows.
		If you perform a measurement in the time domain, this command limits the range of the trace to be analyzed. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: limit: The value range depends on the frequency range or sweep time. The unit is Hz for frequency domain measurements and s for time domain measurements. Unit: HZ"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:X:SLIMits:RIGHt?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZCls:
	"""Z commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("z", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:Z \n
		Snippet: value: float = driver.applications.k14Xnr5G.calculate.marker.z.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the marker position on the z-axis of three-dimensional result displays. This command returns the
		type of value displayed in the selected result display (EVM, Power or Allocation ID) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: position: numeric value Unit: Depends on result display"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:Z?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ZCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ZCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UalternateCls:
	"""Ualternate commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: UpperAltChannel, default value after init: UpperAltChannel.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ualternate", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_upperAltChannel_get', 'repcap_upperAltChannel_set', repcap.UpperAltChannel.Nr1)

	def repcap_upperAltChannel_set(self, upperAltChannel: repcap.UpperAltChannel) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to UpperAltChannel.Default
		Default value after init: UpperAltChannel.Nr1"""
		self._cmd_group.set_repcap_enum_value(upperAltChannel)

	def repcap_upperAltChannel_get(self) -> repcap.UpperAltChannel:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, bandwidth: float, upperAltChannel=repcap.UpperAltChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:BWIDth:UALTernate<ch> \n
		Snippet: driver.sense.power.achannel.bandwidth.ualternate.set(bandwidth = 1.0, upperAltChannel = repcap.UpperAltChannel.Default) \n
		This command defines the channel bandwidth of the upper alternate channels in asymmetrical configurations. To configure
		the bandwidth for the lower alternate channel, use the [SENSe:]POWer:ACHannel:BANDwidth:ALTernate<ch> command.
		Steep-edged channel filters are available for fast ACLR measurements. \n
			:param bandwidth: Range: 100 Hz to 1000 MHz, Unit: Hz
			:param upperAltChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ualternate')
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		upperAltChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(upperAltChannel, repcap.UpperAltChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:BWIDth:UALTernate{upperAltChannel_cmd_val} {param}')

	def get(self, upperAltChannel=repcap.UpperAltChannel.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:BWIDth:UALTernate<ch> \n
		Snippet: value: float = driver.sense.power.achannel.bandwidth.ualternate.get(upperAltChannel = repcap.UpperAltChannel.Default) \n
		This command defines the channel bandwidth of the upper alternate channels in asymmetrical configurations. To configure
		the bandwidth for the lower alternate channel, use the [SENSe:]POWer:ACHannel:BANDwidth:ALTernate<ch> command.
		Steep-edged channel filters are available for fast ACLR measurements. \n
			:param upperAltChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ualternate')
			:return: bandwidth: Range: 100 Hz to 1000 MHz, Unit: Hz"""
		upperAltChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(upperAltChannel, repcap.UpperAltChannel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:BWIDth:UALTernate{upperAltChannel_cmd_val}?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'UalternateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UalternateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.RepeatedCapability import RepeatedCapability
from ... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 22 total commands, 7 Subgroups, 0 group commands
	Repeated Capability: OutputConnector, default value after init: OutputConnector.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_outputConnector_get', 'repcap_outputConnector_set', repcap.OutputConnector.Nr1)

	def repcap_outputConnector_set(self, outputConnector: repcap.OutputConnector) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to OutputConnector.Default
		Default value after init: OutputConnector.Nr1"""
		self._cmd_group.set_repcap_enum_value(outputConnector)

	def repcap_outputConnector_get(self) -> repcap.OutputConnector:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def diq(self):
		"""diq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_diq'):
			from .Diq import DiqCls
			self._diq = DiqCls(self._core, self._cmd_group)
		return self._diq

	@property
	def iqhs(self):
		"""iqhs commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqhs'):
			from .Iqhs import IqhsCls
			self._iqhs = IqhsCls(self._core, self._cmd_group)
		return self._iqhs

	@property
	def uport(self):
		"""uport commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_uport'):
			from .Uport import UportCls
			self._uport = UportCls(self._core, self._cmd_group)
		return self._uport

	@property
	def ifreq(self):
		"""ifreq commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ifreq'):
			from .Ifreq import IfreqCls
			self._ifreq = IfreqCls(self._core, self._cmd_group)
		return self._ifreq

	@property
	def video(self):
		"""video commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_video'):
			from .Video import VideoCls
			self._video = VideoCls(self._core, self._cmd_group)
		return self._video

	@property
	def ademod(self):
		"""ademod commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ademod'):
			from .Ademod import AdemodCls
			self._ademod = AdemodCls(self._core, self._cmd_group)
		return self._ademod

	@property
	def trigger(self):
		"""trigger commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	def clone(self) -> 'OutputCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OutputCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:SPECtrum:MASK:CHECk:Y \n
		Snippet: value: float = driver.applications.k91Wlan.calculate.limit.spectrum.mask.check.y.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		Returns the highest (absolute) power level that exceeds the SEM limit. If no limit was exceeded, an error is returned. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: worst_value: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:SPECtrum:MASK:CHECk:Y?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	def set(self, ref_point: float, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:FIXed:RPOint:Y \n
		Snippet: driver.calculate.deltaMarker.function.fixed.rpoint.y.set(ref_point = 1.0, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command defines the vertical position of the fixed delta marker reference point. The coordinates of the reference
		may be anywhere in the diagram. \n
			:param ref_point: Numeric value that defines the vertical position of the reference. The unit and value range is variable. Unit: DBM
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.decimal_value_to_str(ref_point)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:FIXed:RPOint:Y {param}')

	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> float:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:FIXed:RPOint:Y \n
		Snippet: value: float = driver.calculate.deltaMarker.function.fixed.rpoint.y.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command defines the vertical position of the fixed delta marker reference point. The coordinates of the reference
		may be anywhere in the diagram. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: ref_point: Numeric value that defines the vertical position of the reference. The unit and value range is variable. Unit: DBM"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:FIXed:RPOint:Y?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'YCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = YCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RemoveCls:
	"""Remove commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("remove", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def selected(self):
		"""selected commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_selected'):
			from .Selected import SelectedCls
			self._selected = SelectedCls(self._core, self._cmd_group)
		return self._selected

	def set(self, data_set: float) -> None:
		"""SCPI: HCOPy:TREPort:TEST:REMove \n
		Snippet: driver.hardCopy.treport.test.remove.set(data_set = 1.0) \n
		This command deletes one of the datasets that are currently part of a test report. \n
			:param data_set: Index number of the dataset as shown in the 'Test Report Content Selection' dialog box. If the index number is greater than the number of available datasets, the command returns an error.
		"""
		param = Conversions.decimal_value_to_str(data_set)
		self._core.io.write(f'HCOPy:TREPort:TEST:REMove {param}')

	def clone(self) -> 'RemoveCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RemoveCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqCls:
	"""Iq commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iq", core, parent)

	@property
	def data(self):
		"""data commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def file(self):
		"""file commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	def clone(self) -> 'IqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SequenceCls:
	"""Sequence commands group definition. 11 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequence", core, parent)

	@property
	def dtime(self):
		"""dtime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dtime'):
			from .Dtime import DtimeCls
			self._dtime = DtimeCls(self._core, self._cmd_group)
		return self._dtime

	@property
	def holdoff(self):
		"""holdoff commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_holdoff'):
			from .Holdoff import HoldoffCls
			self._holdoff = HoldoffCls(self._core, self._cmd_group)
		return self._holdoff

	@property
	def ifPower(self):
		"""ifPower commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ifPower'):
			from .IfPower import IfPowerCls
			self._ifPower = IfPowerCls(self._core, self._cmd_group)
		return self._ifPower

	@property
	def level(self):
		"""level commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def rfPower(self):
		"""rfPower commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfPower'):
			from .RfPower import RfPowerCls
			self._rfPower = RfPowerCls(self._core, self._cmd_group)
		return self._rfPower

	@property
	def slope(self):
		"""slope commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slope'):
			from .Slope import SlopeCls
			self._slope = SlopeCls(self._core, self._cmd_group)
		return self._slope

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	def clone(self) -> 'SequenceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SequenceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScaptureCls:
	"""Scapture commands group definition. 3 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scapture", core, parent)

	@property
	def boundary(self):
		"""boundary commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_boundary'):
			from .Boundary import BoundaryCls
			self._boundary = BoundaryCls(self._core, self._cmd_group)
		return self._boundary

	@property
	def tstamp(self):
		"""tstamp commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tstamp'):
			from .Tstamp import TstampCls
			self._tstamp = TstampCls(self._core, self._cmd_group)
		return self._tstamp

	def clone(self) -> 'ScaptureCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScaptureCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqMcompCls:
	"""IqMcomp commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iqMcomp", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:TRACking:IQMComp \n
		Snippet: driver.applications.k91Wlan.sense.tracking.iqMcomp.set(state = False) \n
		Activates or deactivates the compensation for I/Q mismatch (gain imbalance, quadrature offset, I/Q skew, see 'I/Q
		mismatch') . This setting is not available for standards IEEE 802.11b and g (DSSS) . \n
			:param state: ON | OFF | 1 | 0 ON | 1 Compensation for gain imbalance, quadrature offset, and I/Q skew impairments is applied. OFF | 0 Compensation is not applied; this setting is required for measurements strictly according to the IEEE 802.11-2012, IEEE 802.11ac-2013 WLAN standard
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:TRACking:IQMComp {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:TRACking:IQMComp \n
		Snippet: value: bool = driver.applications.k91Wlan.sense.tracking.iqMcomp.get() \n
		Activates or deactivates the compensation for I/Q mismatch (gain imbalance, quadrature offset, I/Q skew, see 'I/Q
		mismatch') . This setting is not available for standards IEEE 802.11b and g (DSSS) . \n
			:return: state: ON | OFF | 1 | 0 ON | 1 Compensation for gain imbalance, quadrature offset, and I/Q skew impairments is applied. OFF | 0 Compensation is not applied; this setting is required for measurements strictly according to the IEEE 802.11-2012, IEEE 802.11ac-2013 WLAN standard"""
		response = self._core.io.query_str(f'SENSe:TRACking:IQMComp?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpperCls:
	"""Upper commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("upper", core, parent)

	def set(self, sb_gaps: enums.SubBlockGaps, spacing: float, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:GAP<gap>:MANual:UPPer \n
		Snippet: driver.sense.power.achannel.spacing.gap.manual.upper.set(sb_gaps = enums.SubBlockGaps.AB, spacing = 1.0, gapChannel = repcap.GapChannel.Default) \n
		This command defines the distance from the sub block to the specified upper gap channel. The required spacing can be
		determined according to the following formula: Spacing = [right sub block CF] - [CF of gap channel] - ([RF bandwidth of
		right sub block] /2) This command is only available for for asymmetrical (manual) configuration of gap channels (see
		[SENSe:]POWer:ACHannel:GAP<gap>:MODE) . \n
			:param sb_gaps: AB | BC | CD | DE | EF | FG | GH Name of the gap, defined by the letters of the surrounding sub blocks (e.g. 'AB' for the gap between sub blocks A and B) .
			:param spacing: Unit: HZ
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sb_gaps', sb_gaps, DataType.Enum, enums.SubBlockGaps), ArgSingle('spacing', spacing, DataType.Float))
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:SPACing:GAP{gapChannel_cmd_val}:MANual:UPPer {param}'.rstrip())

	def get(self, sb_gaps: enums.SubBlockGaps, gapChannel=repcap.GapChannel.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:GAP<gap>:MANual:UPPer \n
		Snippet: value: float = driver.sense.power.achannel.spacing.gap.manual.upper.get(sb_gaps = enums.SubBlockGaps.AB, gapChannel = repcap.GapChannel.Default) \n
		This command defines the distance from the sub block to the specified upper gap channel. The required spacing can be
		determined according to the following formula: Spacing = [right sub block CF] - [CF of gap channel] - ([RF bandwidth of
		right sub block] /2) This command is only available for for asymmetrical (manual) configuration of gap channels (see
		[SENSe:]POWer:ACHannel:GAP<gap>:MODE) . \n
			:param sb_gaps: AB | BC | CD | DE | EF | FG | GH Name of the gap, defined by the letters of the surrounding sub blocks (e.g. 'AB' for the gap between sub blocks A and B) .
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: spacing: Unit: HZ"""
		param = Conversions.enum_scalar_to_str(sb_gaps, enums.SubBlockGaps)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SPACing:GAP{gapChannel_cmd_val}:MANual:UPPer? {param}')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:BURSt:QUAD:QCARrier[:IMMediate] \n
		Snippet: driver.applications.k91Wlan.configure.burst.quad.qcarrier.immediate.set() \n
		This remote control command configures the result display type in window 2 to be 'Quadrature Error vs Carrier'. Results
		are only displayed after a measurement is executed, e.g. using the method RsFsw.Applications.K10x_Lte.Initiate.Immediate.
		set command. Note that the CONF:BURS:<ResultType>:IMM commands change the screen layout to display the 'Magnitude
		Capture' buffer in window 1 at the top of the screen and the selected result type in window 2 below that.
		Any other active windows are closed. Use the LAYout commands to change the display (see 'Working with windows in the
		display') . \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:BURSt:QUAD:QCARrier:IMMediate', opc_timeout_ms)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def x(self):
		"""x commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_x'):
			from .X import XCls
			self._x = XCls(self._core, self._cmd_group)
		return self._x

	def get(self, trace_type: enums.TraceTypeList, window=repcap.Window.Default) -> List[float]:
		"""SCPI: TRACe<n>[:DATA] \n
		Snippet: value: List[float] = driver.applications.k91Wlan.trace.data.get(trace_type = enums.TraceTypeList.LIST, window = repcap.Window.Default) \n
		This command queries current trace data and measurement results from the window previously selected using method RsFsw.
		Applications.K10x_Lte.Display.Window.Subwindow.Select.set. As opposed to the R&S FSW base unit, the window suffix <n> is
		not considered in the R&S FSW WLAN application! Use the method RsFsw.Applications.K10x_Lte.Display.Window.Subwindow.
		Select.set to select the (sub) window before you query trace results! For details see 'Measurement results for
		TRACe<n>[:DATA]? TRACE<n>'. \n
			:param trace_type: TRACE1 | ... | TRACE6 Selects the type of result to be returned. TRACE1 | ... | TRACE6 Returns the trace data for the corresponding trace. Note that for the default WLAN I/Q measurement (Modulation Accuracy, Flatness and Tolerance) , only 1 trace per window (TRACE1) is available. LIST Returns the results of the peak list evaluation for 'Spectrum Emission Mask' measurements.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: trace_ydata: No help available"""
		param = Conversions.enum_scalar_to_str(trace_type, enums.TraceTypeList)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe{window_cmd_val}:DATA? {param}')
		return response

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, externalGen=repcap.ExternalGen.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<gen>[:STATe] \n
		Snippet: driver.source.external.state.set(state = False, externalGen = repcap.ExternalGen.Nr1) \n
		This command activates or deactivates the connected external generator. This command is only valid if External Generator
		Control (R&S FSW-B10) is installed and active. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param externalGen: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.bool_to_str(state)
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		self._core.io.write(f'SOURce:EXTernal{externalGen_cmd_val}:STATe {param}')

	def get(self, externalGen=repcap.ExternalGen.Nr1) -> bool:
		"""SCPI: SOURce:EXTernal<gen>[:STATe] \n
		Snippet: value: bool = driver.source.external.state.get(externalGen = repcap.ExternalGen.Nr1) \n
		This command activates or deactivates the connected external generator. This command is only valid if External Generator
		Control (R&S FSW-B10) is installed and active. \n
			:param externalGen: optional repeated capability selector. Default value: Nr1
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalGen_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PolarityCls:
	"""Polarity commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("polarity", core, parent)

	def set(self, polarity: enums.SlopeType) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:POLarity \n
		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.polarity.set(polarity = enums.SlopeType.NEGative) \n
		This command selects the polarity of an external gate signal. The setting applies both to the edge of an edge-triggered
		signal and the level of a level-triggered signal. \n
			:param polarity: POSitive | NEGative
		"""
		param = Conversions.enum_scalar_to_str(polarity, enums.SlopeType)
		self._core.io.write(f'SENSe:SWEep:EGATe:POLarity {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SlopeType:
		"""SCPI: [SENSe]:SWEep:EGATe:POLarity \n
		Snippet: value: enums.SlopeType = driver.applications.k30NoiseFigure.sense.sweep.egate.polarity.get() \n
		This command selects the polarity of an external gate signal. The setting applies both to the edge of an edge-triggered
		signal and the level of a level-triggered signal. \n
			:return: polarity: POSitive | NEGative"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:POLarity?')
		return Conversions.str_to_scalar_enum(response, enums.SlopeType)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SsetupCls:
	"""Ssetup commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ssetup", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SSETup \n
		Snippet: driver.sense.power.achannel.ssetup.set(state = False) \n
		This command defines whether adjacent channels are defined symmetrically or not. For more information see 'Measurement on
		multi-standard radio (MSR) signals'. \n
			:param state: ON | OFF | 1 | 0 ON | 1 The upper and lower adjacent and alternate channels are defined symmetrically. This is the default behaviour and corresponds to the behavior in firmware versions before 2.10. OFF | 0 The upper and lower channels can be configured differently.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:ACHannel:SSETup {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:ACHannel:SSETup \n
		Snippet: value: bool = driver.sense.power.achannel.ssetup.get() \n
		This command defines whether adjacent channels are defined symmetrically or not. For more information see 'Measurement on
		multi-standard radio (MSR) signals'. \n
			:return: state: ON | OFF | 1 | 0 ON | 1 The upper and lower adjacent and alternate channels are defined symmetrically. This is the default behaviour and corresponds to the behavior in firmware versions before 2.10. OFF | 0 The upper and lower channels can be configured differently."""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SSETup?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SummaryCls:
	"""Summary commands group definition. 93 total commands, 15 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("summary", core, parent)

	@property
	def crest(self):
		"""crest commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_crest'):
			from .Crest import CrestCls
			self._crest = CrestCls(self._core, self._cmd_group)
		return self._crest

	@property
	def evm(self):
		"""evm commands group. 27 Sub-classes, 0 commands."""
		if not hasattr(self, '_evm'):
			from .Evm import EvmCls
			self._evm = EvmCls(self._core, self._cmd_group)
		return self._evm

	@property
	def freqError(self):
		"""freqError commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqError'):
			from .FreqError import FreqErrorCls
			self._freqError = FreqErrorCls(self._core, self._cmd_group)
		return self._freqError

	@property
	def gimbalance(self):
		"""gimbalance commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_gimbalance'):
			from .Gimbalance import GimbalanceCls
			self._gimbalance = GimbalanceCls(self._core, self._cmd_group)
		return self._gimbalance

	@property
	def iqOffset(self):
		"""iqOffset commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqOffset'):
			from .IqOffset import IqOffsetCls
			self._iqOffset = IqOffsetCls(self._core, self._cmd_group)
		return self._iqOffset

	@property
	def ostp(self):
		"""ostp commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ostp'):
			from .Ostp import OstpCls
			self._ostp = OstpCls(self._core, self._cmd_group)
		return self._ostp

	@property
	def power(self):
		"""power commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def quadError(self):
		"""quadError commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_quadError'):
			from .QuadError import QuadErrorCls
			self._quadError = QuadErrorCls(self._core, self._cmd_group)
		return self._quadError

	@property
	def rbp(self):
		"""rbp commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rbp'):
			from .Rbp import RbpCls
			self._rbp = RbpCls(self._core, self._cmd_group)
		return self._rbp

	@property
	def nbPower(self):
		"""nbPower commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_nbPower'):
			from .NbPower import NbPowerCls
			self._nbPower = NbPowerCls(self._core, self._cmd_group)
		return self._nbPower

	@property
	def rfError(self):
		"""rfError commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfError'):
			from .RfError import RfErrorCls
			self._rfError = RfErrorCls(self._core, self._cmd_group)
		return self._rfError

	@property
	def rssi(self):
		"""rssi commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rssi'):
			from .Rssi import RssiCls
			self._rssi = RssiCls(self._core, self._cmd_group)
		return self._rssi

	@property
	def rstp(self):
		"""rstp commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rstp'):
			from .Rstp import RstpCls
			self._rstp = RstpCls(self._core, self._cmd_group)
		return self._rstp

	@property
	def serror(self):
		"""serror commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_serror'):
			from .Serror import SerrorCls
			self._serror = SerrorCls(self._core, self._cmd_group)
		return self._serror

	@property
	def tframe(self):
		"""tframe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tframe'):
			from .Tframe import TframeCls
			self._tframe = TframeCls(self._core, self._cmd_group)
		return self._tframe

	def clone(self) -> 'SummaryCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SummaryCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:UTESummary:ALL \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.uteSummary.all.get() \n
		Returns the results of the 'Unused Tone Error' Summary. The result is a comma-separated list of values for up to 37
		measurement points in the channel. Which subcarriers are measured depends on the size and position of the RU being
		transmitted. This result is required by the IEEE 802.11ax standard for HE trigger-based PPDUs with a maximum channel
		bandwidth of 80 MHz. \n
			:return: result: -35 dB LHS | RUIdx-3 | RUIdx-2 | RUIdx-1 | RUIdx | RUIdx+1 | RUIdx+2 | RUIdx+3 | -35 dB RHS Set of n subcarriers, where n is the number of subcarriers in the resource unit to be checked. For details see 'Unused tone error' Unit: -"""
		response = self._core.io.query_str(f'FETCh:UTESummary:ALL?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ApCls:
	"""Ap commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: AntennaPort3k, default value after init: AntennaPort3k.Nr3000"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ap", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_antennaPort3k_get', 'repcap_antennaPort3k_set', repcap.AntennaPort3k.Nr3000)

	def repcap_antennaPort3k_set(self, antennaPort3k: repcap.AntennaPort3k) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AntennaPort3k.Default
		Default value after init: AntennaPort3k.Nr3000"""
		self._cmd_group.set_repcap_enum_value(antennaPort3k)

	def repcap_antennaPort3k_get(self) -> repcap.AntennaPort3k:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, state: bool, carrierComponent=repcap.CarrierComponent.Default, antennaPortConfig=repcap.AntennaPortConfig.Default, antennaPort3k=repcap.AntennaPort3k.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:PAMapping<cf>:CSIRs:AP<AntennaPort3k> \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.pamapping.csirs.ap.set(state = False, carrierComponent = repcap.CarrierComponent.Default, antennaPortConfig = repcap.AntennaPortConfig.Default, antennaPort3k = repcap.AntennaPort3k.Default) \n
		This command selects the antenna port(s) on which the CSI reference signal is transmitted. \n
			:param state: ON | OFF | 1 | 0 Turns a specific CSI-RS antenna port on and off. ALL | NONE Turns all CSI-RS antenna port on and off.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param antennaPortConfig: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pamapping')
			:param antennaPort3k: optional repeated capability selector. Default value: Nr3000 (settable in the interface 'Ap')
		"""
		param = Conversions.bool_to_str(state)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		antennaPortConfig_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPortConfig, repcap.AntennaPortConfig)
		antennaPort3k_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPort3k, repcap.AntennaPort3k)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:PAMapping{antennaPortConfig_cmd_val}:CSIRs:AP{antennaPort3k_cmd_val} {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, antennaPortConfig=repcap.AntennaPortConfig.Default, antennaPort3k=repcap.AntennaPort3k.Default) -> bool:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:PAMapping<cf>:CSIRs:AP<AntennaPort3k> \n
		Snippet: value: bool = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.pamapping.csirs.ap.get(carrierComponent = repcap.CarrierComponent.Default, antennaPortConfig = repcap.AntennaPortConfig.Default, antennaPort3k = repcap.AntennaPort3k.Default) \n
		This command selects the antenna port(s) on which the CSI reference signal is transmitted. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param antennaPortConfig: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pamapping')
			:param antennaPort3k: optional repeated capability selector. Default value: Nr3000 (settable in the interface 'Ap')
			:return: state: ON | OFF | 1 | 0 Turns a specific CSI-RS antenna port on and off. ALL | NONE Turns all CSI-RS antenna port on and off."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		antennaPortConfig_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPortConfig, repcap.AntennaPortConfig)
		antennaPort3k_cmd_val = self._cmd_group.get_repcap_cmd_value(antennaPort3k, repcap.AntennaPort3k)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:PAMapping{antennaPortConfig_cmd_val}:CSIRs:AP{antennaPort3k_cmd_val}?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'ApCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ApCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AmPowerCls:
	"""AmPower commands group definition. 7 total commands, 6 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("amPower", core, parent)

	@property
	def average(self):
		"""average commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_average'):
			from .Average import AverageCls
			self._average = AverageCls(self._core, self._cmd_group)
		return self._average

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def maximum(self):
		"""maximum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_maximum'):
			from .Maximum import MaximumCls
			self._maximum = MaximumCls(self._core, self._cmd_group)
		return self._maximum

	@property
	def minimum(self):
		"""minimum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_minimum'):
			from .Minimum import MinimumCls
			self._minimum = MinimumCls(self._core, self._cmd_group)
		return self._minimum

	@property
	def limit(self):
		"""limit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def standardDev(self):
		"""standardDev commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_standardDev'):
			from .StandardDev import StandardDevCls
			self._standardDev = StandardDevCls(self._core, self._cmd_group)
		return self._standardDev

	def get(self, query_range: enums.SelectionRange) -> str:
		"""SCPI: [SENSe]:PULSe:TSIDelobe:AMPower \n
		Snippet: value: str = driver.applications.k6Pulse.sense.pulse.tsidelobe.amPower.get(query_range = enums.SelectionRange.ALL) \n
		Returns the average mainlobe level for the specified pulse(s) . \n
			:param query_range: SELected | CURRent | ALL SELected Currently selected pulse CURRent Detected pulses in the current capture buffer ALL All detected pulses in the entire measurement.
			:return: result: char_data"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRange)
		response = self._core.io.query_str(f'SENSe:PULSe:TSIDelobe:AMPower? {param}')
		return trim_str_response(response)

	def clone(self) -> 'AmPowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AmPowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortsCls:
	"""Ports commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ports", core, parent)

	@property
	def to(self):
		"""to commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_to'):
			from .To import ToCls
			self._to = ToCls(self._core, self._cmd_group)
		return self._to

	@property
	def fromPy(self):
		"""fromPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fromPy'):
			from .FromPy import FromPyCls
			self._fromPy = FromPyCls(self._core, self._cmd_group)
		return self._fromPy

	def clone(self) -> 'PortsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PortsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:DEModsetting:ALL \n
		Snippet: driver.applications.k14Xnr5G.massMemory.load.demodSetting.all.set(filename = '1') \n
		This command restores the signal description of multiple carriers from a single file. \n
			:param filename: String containing the path and name of the file. The file extension is .ccallocation.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'MMEMory:LOAD:DEModsetting:ALL {param}')

	def get(self) -> str:
		"""SCPI: MMEMory:LOAD:DEModsetting:ALL \n
		Snippet: value: str = driver.applications.k14Xnr5G.massMemory.load.demodSetting.all.get() \n
		This command restores the signal description of multiple carriers from a single file. \n
			:return: filename: String containing the path and name of the file. The file extension is .ccallocation."""
		response = self._core.io.query_str(f'MMEMory:LOAD:DEModsetting:ALL?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StabilityCls:
	"""Stability commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stability", core, parent)

	def set(self, yaxis: enums.PulseYaxisItem, xaxis: enums.PulseAxisItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TRENd:STABility \n
		Snippet: driver.applications.k6Pulse.calculate.trend.stability.set(yaxis = enums.PulseYaxisItem.AMPLitude, xaxis = enums.PulseAxisItems.DCYCle, window = repcap.Window.Default) \n
		No command help available \n
			:param yaxis: No help available
			:param xaxis: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('yaxis', yaxis, DataType.Enum, enums.PulseYaxisItem), ArgSingle('xaxis', xaxis, DataType.Enum, enums.PulseAxisItems))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRENd:STABility {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	@property
	def resolution(self):
		"""resolution commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resolution'):
			from .Resolution import ResolutionCls
			self._resolution = ResolutionCls(self._core, self._cmd_group)
		return self._resolution

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	def set(self, state: bool, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:COUNt \n
		Snippet: driver.calculate.marker.count.set(state = False, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command turns the frequency counter at the marker position on and off. The frequency counter works for one marker
		only. If you perform a frequency count with another marker, the R&S FSW deactivates the frequency count of the first
		marker. To get a valid result, you have to perform a complete measurement with synchronization to the end of the
		measurement before reading out the result. This is only possible for single sweep mode. See also method RsFsw.
		Applications.K10x_Lte.Initiate.Continuous.set. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:COUNt {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> bool:
		"""SCPI: CALCulate<n>:MARKer<m>:COUNt \n
		Snippet: value: bool = driver.calculate.marker.count.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command turns the frequency counter at the marker position on and off. The frequency counter works for one marker
		only. If you perform a frequency count with another marker, the R&S FSW deactivates the frequency count of the first
		marker. To get a valid result, you have to perform a complete measurement with synchronization to the end of the
		measurement before reading out the result. This is only possible for single sweep mode. See also method RsFsw.
		Applications.K10x_Lte.Initiate.Continuous.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:COUNt?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'CountCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CountCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExecCls:
	"""Exec commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("exec", core, parent)

	def set(self) -> None:
		"""SCPI: SYSTem:PRESet:CHANnel[:EXEC] \n
		Snippet: driver.system.preset.channel.exec.set() \n
		This command restores the default instrument settings in the current channel. Use INST:SEL to select the channel.
		For details see 'Restoring the default instrument configuration (preset) '. \n
		"""
		self._core.io.write(f'SYSTem:PRESet:CHANnel:EXEC')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:PRESet:CHANnel[:EXEC] \n
		Snippet: driver.system.preset.channel.exec.set_with_opc() \n
		This command restores the default instrument settings in the current channel. Use INST:SEL to select the channel.
		For details see 'Restoring the default instrument configuration (preset) '. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:PRESet:CHANnel:EXEC', opc_timeout_ms)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def get(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default) -> float:
		"""SCPI: FETCh[:CC<cc>][:ISRC][:FRAMe<fr>]:SUMMary:BLER:MAXimum \n
		Snippet: value: float = driver.applications.k14Xnr5G.fetch.cc.isrc.frame.summary.bler.maximum.get(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default) \n
		This command queries the EVM of all resource elements.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on throughput measurement ([SENSe:]NR5G:TRACking:TPUT:STATe) .
			- Turn on BLER measurement (method RsFsw.Applications.K91_Wlan.Display.Window.Table.Item.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:return: bler: Unit: PCT"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		response = self._core.io.query_str(f'FETCh:CC{carrierComponent_cmd_val}:ISRC:FRAMe{frame_cmd_val}:SUMMary:BLER:MAXimum?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ...........Internal.Types import DataType
from ...........Internal.ArgSingleList import ArgSingleList
from ...........Internal.ArgSingle import ArgSingle
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AbsoluteCls:
	"""Absolute commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("absolute", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, sb_gaps: enums.SubBlockGaps, limit: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>:MANual:LOWer:ABSolute \n
		Snippet: driver.applications.k14Xnr5G.calculate.limit.acPower.gap.manual.lower.absolute.set(sb_gaps = enums.SubBlockGaps.AB, limit = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param sb_gaps: No help available
			:param limit: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sb_gaps', sb_gaps, DataType.Enum, enums.SubBlockGaps), ArgSingle('limit', limit, DataType.Float))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:MANual:LOWer:ABSolute {param}'.rstrip())

	def get(self, sb_gaps: enums.SubBlockGaps, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>:MANual:LOWer:ABSolute \n
		Snippet: value: float = driver.applications.k14Xnr5G.calculate.limit.acPower.gap.manual.lower.absolute.get(sb_gaps = enums.SubBlockGaps.AB, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param sb_gaps: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: limit: No help available"""
		param = Conversions.enum_scalar_to_str(sb_gaps, enums.SubBlockGaps)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:MANual:LOWer:ABSolute? {param}')
		return Conversions.str_to_float(response)

	def clone(self) -> 'AbsoluteCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AbsoluteCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GroupCls:
	"""Group commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("group", core, parent)

	def set(self, group: int, window=repcap.Window.Default) -> None:
		"""SCPI: SENSe[:WINDow<n>]:DISPlay:RWConfig:GROup \n
		Snippet: driver.applications.k149Uwb.sense.window.display.rwConfig.group.set(group = 1, window = repcap.Window.Default) \n
		Sets the Group for this window and for any windows this window is linked to. \n
			:param group: 1..n Window
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.decimal_value_to_str(group)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'SENSe:WINDow{window_cmd_val}:DISPlay:RWConfig:GROup {param}')

	def get(self, window=repcap.Window.Default) -> int:
		"""SCPI: SENSe[:WINDow<n>]:DISPlay:RWConfig:GROup \n
		Snippet: value: int = driver.applications.k149Uwb.sense.window.display.rwConfig.group.get(window = repcap.Window.Default) \n
		Sets the Group for this window and for any windows this window is linked to. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: group: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'SENSe:WINDow{window_cmd_val}:DISPlay:RWConfig:GROup?')
		return Conversions.str_to_int(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LoneCls:
	"""Lone commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lone", core, parent)

	def set(self, value: float, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, csiRs=repcap.CsiRs.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:CSI<csi>:LONE \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.csi.lone.set(value = 1.0, carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, csiRs = repcap.CsiRs.Default) \n
		This command defines parameter l1of the CSI-RS.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a location setting that supports l1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Csi.Row.set) .
			INTRO_CMD_HELP: Effects of this command \n
			- Changing l1 can have an effect on the value of l0 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Csi.Lzero.set) . \n
			:param value: The range of values and default value depend on the selected CSI-RS location setting.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param csiRs: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Csi')
		"""
		param = Conversions.decimal_value_to_str(value)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		csiRs_cmd_val = self._cmd_group.get_repcap_cmd_value(csiRs, repcap.CsiRs)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:CSI{csiRs_cmd_val}:LONE {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default, csiRs=repcap.CsiRs.Default) -> float:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:CSI<csi>:LONE \n
		Snippet: value: float = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.frame.bwPart.csi.lone.get(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default, csiRs = repcap.CsiRs.Default) \n
		This command defines parameter l1of the CSI-RS.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select a location setting that supports l1 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Csi.Row.set) .
			INTRO_CMD_HELP: Effects of this command \n
			- Changing l1 can have an effect on the value of l0 (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Downlink.Cc.Frame.BwPart.Csi.Lzero.set) . \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:param csiRs: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Csi')
			:return: value: The range of values and default value depend on the selected CSI-RS location setting."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		csiRs_cmd_val = self._cmd_group.get_repcap_cmd_value(csiRs, repcap.CsiRs)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:CSI{csiRs_cmd_val}:LONE?')
		return Conversions.str_to_float(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def memory(self):
		"""memory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_memory'):
			from .Memory import MemoryCls
			self._memory = MemoryCls(self._core, self._cmd_group)
		return self._memory

	@property
	def memoryall(self):
		"""memoryall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_memoryall'):
			from .Memoryall import MemoryallCls
			self._memoryall = MemoryallCls(self._core, self._cmd_group)
		return self._memoryall

	def get(self) -> List[float]:
		"""SCPI: TRACe:IQ:DATA \n
		Snippet: value: List[float] = driver.applications.k149Uwb.trace.iq.data.get() \n
		No command help available \n
			:return: iq_data: No help available"""
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe:IQ:DATA?')
		return response

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsCaptureCls:
	"""CsCapture commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csCapture", core, parent)

	def set(self, mode: enums.SweepMode) -> None:
		"""SCPI: CONFigure[:NR5G]:CSCapture \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.csCapture.set(mode = enums.SweepMode.AUTO) \n
		This command selects the capture mode for measurements on multiple component carriers. \n
			:param mode: AUTO Automatically selects the number of component carriers that can be analyzed in a single capture. If there are more carriers than can be analyzed in a single measurement, the other carriers are analyzed in subsequent measurements. SINGle Capture each component carrier subsequently in individual measurements.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SweepMode)
		self._core.io.write(f'CONFigure:NR5G:CSCapture {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SweepMode:
		"""SCPI: CONFigure[:NR5G]:CSCapture \n
		Snippet: value: enums.SweepMode = driver.applications.k14Xnr5G.configure.nr5G.csCapture.get() \n
		This command selects the capture mode for measurements on multiple component carriers. \n
			:return: mode: AUTO Automatically selects the number of component carriers that can be analyzed in a single capture. If there are more carriers than can be analyzed in a single measurement, the other carriers are analyzed in subsequent measurements. SINGle Capture each component carrier subsequently in individual measurements."""
		response = self._core.io.query_str(f'CONFigure:NR5G:CSCapture?')
		return Conversions.str_to_scalar_enum(response, enums.SweepMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoCcCls:
	"""NoCc commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("noCc", core, parent)

	def set(self, carrier: float) -> None:
		"""SCPI: CONFigure[:LTE]:NOCC \n
		Snippet: driver.applications.k10Xlte.configure.lte.noCc.set(carrier = 1.0) \n
		This command selects the number of component carriers analyzed in the measurement. \n
			:param carrier: Number of the component carriers that you would like to measure. The range depends on the measurement. For more information see 'Carrier Aggregation'.
		"""
		param = Conversions.decimal_value_to_str(carrier)
		self._core.io.write(f'CONFigure:LTE:NOCC {param}')

	def get(self) -> float:
		"""SCPI: CONFigure[:LTE]:NOCC \n
		Snippet: value: float = driver.applications.k10Xlte.configure.lte.noCc.get() \n
		This command selects the number of component carriers analyzed in the measurement. \n
			:return: carrier: Number of the component carriers that you would like to measure. The range depends on the measurement. For more information see 'Carrier Aggregation'."""
		response = self._core.io.query_str(f'CONFigure:LTE:NOCC?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:EGAin[:STATe] \n
		Snippet: driver.inputPy.egain.state.set(state = False, inputIx = repcap.InputIx.Default) \n
		Before this command can be used, the external preamplifier must be connected to the R&S FSW. See the preamplifier's
		documentation for details. When activated, the R&S FSW automatically compensates the magnitude and phase characteristics
		of the external preamplifier in the measurement results. Note that when an optional external preamplifier is activated,
		the internal preamplifier is automatically disabled, and vice versa. For R&S FSW85 models with two RF inputs, you must
		enable correction from the external preamplifier for each input individually. Correction cannot be enabled for both
		inputs at the same time. When deactivated, no compensation is performed even if an external preamplifier remains
		connected. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 No data correction is performed based on the external preamplifier ON | 1 Performs data corrections based on the external preamplifier
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.bool_to_str(state)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:EGAin:STATe {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> bool:
		"""SCPI: INPut<ip>:EGAin[:STATe] \n
		Snippet: value: bool = driver.inputPy.egain.state.get(inputIx = repcap.InputIx.Default) \n
		Before this command can be used, the external preamplifier must be connected to the R&S FSW. See the preamplifier's
		documentation for details. When activated, the R&S FSW automatically compensates the magnitude and phase characteristics
		of the external preamplifier in the measurement results. Note that when an optional external preamplifier is activated,
		the internal preamplifier is automatically disabled, and vice versa. For R&S FSW85 models with two RF inputs, you must
		enable correction from the external preamplifier for each input individually. Correction cannot be enabled for both
		inputs at the same time. When deactivated, no compensation is performed even if an external preamplifier remains
		connected. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: state: ON | OFF | 0 | 1 OFF | 0 No data correction is performed based on the external preamplifier ON | 1 Performs data corrections based on the external preamplifier"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:EGAin:STATe?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: CONFigure:PSWeep:ADJust:LEVel[:STATe] \n
		Snippet: driver.applications.k18AmplifierEt.configure.psweep.adjust.level.state.set(state = False) \n
		This command turns synchronization of the generator output level and the analyzer reference level on and off. When you
		synchronize the levels, it is recommended to also define the expected gain of the DUT with method RsFsw.Applications.
		K18_AmplifierEt.Configure.Psweep.Expected.Gain.set.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select 'Generator Power' as one of the parameters. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:PSWeep:ADJust:LEVel:STATe {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure:PSWeep:ADJust:LEVel[:STATe] \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.configure.psweep.adjust.level.state.get() \n
		This command turns synchronization of the generator output level and the analyzer reference level on and off. When you
		synchronize the levels, it is recommended to also define the expected gain of the DUT with method RsFsw.Applications.
		K18_AmplifierEt.Configure.Psweep.Expected.Gain.set.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select 'Generator Power' as one of the parameters. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'CONFigure:PSWeep:ADJust:LEVel:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DemodCls:
	"""Demod commands group definition. 8 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("demod", core, parent)

	@property
	def mac(self):
		"""mac commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_mac'):
			from .Mac import MacCls
			self._mac = MacCls(self._core, self._cmd_group)
		return self._mac

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def payload(self):
		"""payload commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_payload'):
			from .Payload import PayloadCls
			self._payload = PayloadCls(self._core, self._cmd_group)
		return self._payload

	@property
	def phrRate(self):
		"""phrRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phrRate'):
			from .PhrRate import PhrRateCls
			self._phrRate = PhrRateCls(self._core, self._cmd_group)
		return self._phrRate

	@property
	def sts(self):
		"""sts commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_sts'):
			from .Sts import StsCls
			self._sts = StsCls(self._core, self._cmd_group)
		return self._sts

	def clone(self) -> 'DemodCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DemodCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
